#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const BaseConsoleApplication_1 = require("./BaseConsoleApplication");
const ConsoleLogger_1 = require("../infrastructure/logger/ConsoleLogger");
const JavaScriptCodeGenerator_1 = require("../infrastructure/codeGeneration/JavaScriptCodeGenerator");
const TypescriptCodeGenerator_1 = require("../infrastructure/codeGeneration/TypescriptCodeGenerator");
const SwiftCodeGenerator_1 = require("../infrastructure/codeGeneration/SwiftCodeGenerator");
const JSONSchemeGenerator_1 = require("../infrastructure/schemeGeneration/JSONSchemeGenerator");
const JSONSchemeSource_1 = require("../infrastructure/schemeGeneration/sources/JSONSchemeSource");
const path_1 = require("path");
const Modelify_1 = require("../application/Modelify");
class ModelifyApplication extends BaseConsoleApplication_1.default {
    constructor() {
        super();
        const args = this.getArgs();
        const lang = args.lang;
        const input = args.i;
        const output = args.o;
        if (!lang || !input || !output)
            this.die('\nWrong args\n\n' +
                'Usage: modelify -lang=js -i=/path/to/your.json -o=/path/to/out/dir\n\n' +
                'Available languages: js, ts, swift');
        this.run(lang, input, output);
    }
    run(lang, input, output) {
        return __awaiter(this, void 0, void 0, function* () {
            let logger = new ConsoleLogger_1.default();
            let json = JSON.parse(yield this.readFile(input));
            let codeGenerator = this.getCodeGeneratorByLang(lang);
            let schemeGenerator = new JSONSchemeGenerator_1.default();
            let modelify = new Modelify_1.default(schemeGenerator, codeGenerator, logger);
            let files = modelify.generate(new JSONSchemeSource_1.default(json));
            for (let file of files) {
                yield this.saveToFile(path_1.join(output, file.fileName), file.code.render());
            }
            console.log('Done!');
        });
    }
    getCodeGeneratorByLang(lang) {
        if (lang === 'js')
            return new JavaScriptCodeGenerator_1.default();
        if (lang === 'ts')
            return new TypescriptCodeGenerator_1.default();
        if (lang === 'swift')
            return new SwiftCodeGenerator_1.default();
        throw new Error('No code generator for ' + lang);
    }
}
new ModelifyApplication();
//# sourceMappingURL=ModelifyApplication.js.map