"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const JSONSchemeGenerator_1 = require("../infrastructure/schemeGeneration/JSONSchemeGenerator");
const JSONSchemeSource_1 = require("../infrastructure/schemeGeneration/sources/JSONSchemeSource");
const assert_1 = require("assert");
const ClassScheme_1 = require("../domain/schema/schema/ClassScheme");
const ClassField_1 = require("../domain/schema/schema/ClassField");
const NumberType_1 = require("../domain/schema/types/NumberType");
const StringType_1 = require("../domain/schema/types/StringType");
const AnyType_1 = require("../domain/schema/types/AnyType");
const BooleanType_1 = require("../domain/schema/types/BooleanType");
const CustomType_1 = require("../domain/schema/types/CustomType");
const VectorType_1 = require("../domain/schema/types/VectorType");
let schemeGenerator = new JSONSchemeGenerator_1.default();
function testBaseTypes() {
    let source = new JSONSchemeSource_1.default({
        a: 1,
        b: '2',
        c: true,
        d: null,
        e: undefined
    });
    let generatedScheme = schemeGenerator.generate(source);
    let expectedScheme = [
        new ClassScheme_1.default('Root', [
            new ClassField_1.default('a', new NumberType_1.default(), ''),
            new ClassField_1.default('b', new StringType_1.default(), ''),
            new ClassField_1.default('c', new BooleanType_1.default(), ''),
            new ClassField_1.default('d', new AnyType_1.default(), ''),
            new ClassField_1.default('e', new AnyType_1.default(), '')
        ])
    ];
    assert_1.deepStrictEqual(expectedScheme, generatedScheme);
}
exports.testBaseTypes = testBaseTypes;
function testCustomTypes() {
    let source = new JSONSchemeSource_1.default({
        a: {
            a: 1,
            b: '2',
            c: true,
            d: null,
            e: undefined
        }
    });
    let generatedScheme = schemeGenerator.generate(source);
    let expectedScheme = [
        new ClassScheme_1.default('A', [
            new ClassField_1.default('a', new NumberType_1.default(), ''),
            new ClassField_1.default('b', new StringType_1.default(), ''),
            new ClassField_1.default('c', new BooleanType_1.default(), ''),
            new ClassField_1.default('d', new AnyType_1.default(), ''),
            new ClassField_1.default('e', new AnyType_1.default(), '')
        ]),
        new ClassScheme_1.default('Root', [
            new ClassField_1.default('a', new CustomType_1.default('A'), '')
        ])
    ];
    assert_1.deepStrictEqual(expectedScheme, generatedScheme);
}
exports.testCustomTypes = testCustomTypes;
function testVectorType() {
    let source = new JSONSchemeSource_1.default({
        a: {
            a: [1],
            b: ['2'],
            c: [true],
            d: [null],
            e: [undefined],
            f: [{ a: 1 }]
        }
    });
    let generatedScheme = schemeGenerator.generate(source);
    let expectedScheme = [
        new ClassScheme_1.default('F', [
            new ClassField_1.default('a', new NumberType_1.default(), '')
        ]),
        new ClassScheme_1.default('A', [
            new ClassField_1.default('a', new VectorType_1.default(new NumberType_1.default()), ''),
            new ClassField_1.default('b', new VectorType_1.default(new StringType_1.default()), ''),
            new ClassField_1.default('c', new VectorType_1.default(new BooleanType_1.default()), ''),
            new ClassField_1.default('d', new VectorType_1.default(new AnyType_1.default()), ''),
            new ClassField_1.default('e', new VectorType_1.default(new AnyType_1.default()), ''),
            new ClassField_1.default('f', new VectorType_1.default(new CustomType_1.default('F')), '')
        ]),
        new ClassScheme_1.default('Root', [
            new ClassField_1.default('a', new CustomType_1.default('A'), '')
        ])
    ];
    assert_1.deepStrictEqual(expectedScheme, generatedScheme);
}
exports.testVectorType = testVectorType;
//# sourceMappingURL=JSONSchemeGeneratorTest.js.map